import { ApiParseResponseJson, ApiRequestFetchPolicy, ApiRequestOptions, ApiSerializeRequestJson, ResponseBody } from './typings';
export declare class Api {
    defaultFetchPolicy: ApiRequestFetchPolicy;
    private responseBodyCache;
    private requestManager;
    private emitter;
    constructor(params?: {
        /**
         * Base URL of API to prefix all requests with
         */
        baseUrl?: string;
        /**
         * When set, overrides the fetch policy for all requests.
         *
         * Note that this differs from the `useApiQuery` default fetch policy,
         * which can be configured using `ApiProvider`.
         */
        defaultFetchPolicy?: ApiRequestFetchPolicy;
        /**
         * When provided, all API JSON request bodies will be run
         * through this transformation function before the API request
         */
        serializeRequestJson?: ApiSerializeRequestJson;
        /**
         * When provided, all API JSON response bodies will be run
         * through this transformation function before returning the response
         */
        parseResponseJson?: ApiParseResponseJson;
    });
    /**
     * Makes an API request
     */
    request: <TResponseBody extends ResponseBody>(params: import("./typings").ApiGetDeleteRequestParams<"GET", TResponseBody> | import("./typings").ApiMutationRequestParams<"POST", TResponseBody> | import("./typings").ApiMutationRequestParams<"PUT", TResponseBody> | import("./typings").ApiMutationRequestParams<"PATCH", TResponseBody> | import("./typings").ApiGetDeleteRequestParams<"DELETE", TResponseBody>, options?: ApiRequestOptions) => Promise<TResponseBody>;
    /**
     * Returns `true` if a `GET` of `DELETE` request matches params
     */
    requestInProgress: (params: import("./typings").ApiGetDeleteRequestParams<"GET", ResponseBody> | import("./typings").ApiMutationRequestParams<"POST", ResponseBody> | import("./typings").ApiMutationRequestParams<"PUT", ResponseBody> | import("./typings").ApiMutationRequestParams<"PATCH", ResponseBody> | import("./typings").ApiGetDeleteRequestParams<"DELETE", ResponseBody>) => boolean;
    /**
     * Saves a response directly to the cache
     */
    writeCachedResponse: <TResponseBody extends ResponseBody>(params: import("./typings").ApiGetDeleteRequestParams<"GET", TResponseBody> | import("./typings").ApiMutationRequestParams<"POST", TResponseBody> | import("./typings").ApiMutationRequestParams<"PUT", TResponseBody> | import("./typings").ApiMutationRequestParams<"PATCH", TResponseBody> | import("./typings").ApiGetDeleteRequestParams<"DELETE", TResponseBody>, responseBody: TResponseBody) => void;
    /**
     * Reads a response directly from the cache
     *
     * The main reason you would use this over `Api#request` with a cached
     * fetch policy is that this runs synchronously.
     *
     * Note that if there is a cache miss, it will return `undefined`
     */
    readCachedResponse: <TResponseBody extends ResponseBody>(params: import("./typings").ApiGetDeleteRequestParams<"GET", TResponseBody> | import("./typings").ApiMutationRequestParams<"POST", TResponseBody> | import("./typings").ApiMutationRequestParams<"PUT", TResponseBody> | import("./typings").ApiMutationRequestParams<"PATCH", TResponseBody> | import("./typings").ApiGetDeleteRequestParams<"DELETE", TResponseBody>) => TResponseBody;
    /**
     * Subscribes to cache updates for a given param's response
     */
    onCacheUpdate: <TResponseBody extends ResponseBody>(params: import("./typings").ApiGetDeleteRequestParams<"GET", TResponseBody> | import("./typings").ApiMutationRequestParams<"POST", TResponseBody> | import("./typings").ApiMutationRequestParams<"PUT", TResponseBody> | import("./typings").ApiMutationRequestParams<"PATCH", TResponseBody> | import("./typings").ApiGetDeleteRequestParams<"DELETE", TResponseBody>, listener: (responseBody: TResponseBody) => void) => () => void;
    /**
     * Returns the base url concatenated with the provided path
     */
    buildUrl: (path: string) => string;
    /**
     * Set default headers to be passed to all API requests.
     * Useful for setting an authentication token.
     *
     * @param key Header key
     * @param value Header value
     */
    setDefaultHeader: (key: string, value: string) => void;
    /**
     * Configuring an error handler to be called on error
     */
    onError: (listener: (error: Error) => void) => () => void;
}
