import { RequestFetcher, RequestFetcherParams } from '../typings';
/**
 * Is called by the `RequestManager` to make the request over the network.
 *
 * Responsible for:
 * - Throwing ApiErrors for non-200 level errors
 * - Parsing response bodies
 */
export declare class ApiRequestFetcher implements RequestFetcher {
    getResponse: (params: RequestFetcherParams) => Promise<{
        responseBody: string | object | Blob | null;
        responseType: "json" | "text" | "blob" | null;
    }>;
    /**
     * Generates a `Request` instance to be passed directly to `fetch`
     */
    private createRequest;
    /**
     * Parses response body from `fetch`'s `Response`
     */
    private parseResponseBody;
    /**
     * Attempts to infer the response type for parsing using the
     * 'Content-Type' header
     */
    private inferResponseTypeUsingContentType;
}
