import { ApiParseResponseJson, ApiRequestOptions, ApiSerializeRequestJson, RequestFetcher, ResponseBody } from '../typings';
/**
 * The request manager is responsible for managing API requests.
 *
 * Responsibilities include:
 * - Implementing `getRequestBody` which is called by `Api`
 * - Caching in-progress GET requests
 * - Detecting a JSON request body by stringifying and setting the appropriate Content-Type headers
 * - Serializing / parsing JSON requests & responses
 */
export declare class ApiRequestManager {
    baseUrl: string;
    private emitter;
    private requestFetcher;
    private serializeRequestJson;
    private parseResponseJson;
    private defaultHeaders;
    private inProgressRequestCache;
    constructor(params: {
        /**
         * Base URL of API to prefix all requests with
         */
        baseUrl?: string;
        /**
         * When provided, all API JSON request bodies will be run
         * through this transformation function before the API request
         */
        serializeRequestJson?: ApiSerializeRequestJson;
        /**
         * When provided, all API JSON response bodies will be run
         * through this transformation function before returning the response
         */
        parseResponseJson?: ApiParseResponseJson;
        requestFetcher?: RequestFetcher;
    });
    /**
     * Returns a promise that resolves with the response body.
     *
     * If there is an in-progress request, and `options.deduplicate` is `true`,
     * it will return the same promise.
     *
     * On a successful fetch, it will cache the response unless `fetchPolicy` is `'no-cache'`
     */
    getResponseBody: <TResponseBody extends ResponseBody>(params: import("../typings").ApiGetDeleteRequestParams<"GET", TResponseBody> | import("../typings").ApiMutationRequestParams<"POST", TResponseBody> | import("../typings").ApiMutationRequestParams<"PUT", TResponseBody> | import("../typings").ApiMutationRequestParams<"PATCH", TResponseBody> | import("../typings").ApiGetDeleteRequestParams<"DELETE", TResponseBody>, options: ApiRequestOptions) => Promise<TResponseBody | null>;
    private createRequestPromise;
    /**
     * Configuring an error handler to be called on error
     */
    onReceivedResponseBody: (listener: (params: import("../typings").ApiGetDeleteRequestParams<"GET", ResponseBody> | import("../typings").ApiMutationRequestParams<"POST", ResponseBody> | import("../typings").ApiMutationRequestParams<"PUT", ResponseBody> | import("../typings").ApiMutationRequestParams<"PATCH", ResponseBody> | import("../typings").ApiGetDeleteRequestParams<"DELETE", ResponseBody>, responseBody: ResponseBody) => void) => () => void;
    /**
     * Configuring an error handler to be called on error
     */
    onError: (listener: (error: Error) => void) => () => void;
    /**
     * Returns `true` if a `GET` request matches params
     */
    requestInProgress: (params: import("../typings").ApiGetDeleteRequestParams<"GET", ResponseBody> | import("../typings").ApiMutationRequestParams<"POST", ResponseBody> | import("../typings").ApiMutationRequestParams<"PUT", ResponseBody> | import("../typings").ApiMutationRequestParams<"PATCH", ResponseBody> | import("../typings").ApiGetDeleteRequestParams<"DELETE", ResponseBody>) => boolean;
    /**
     * Set default headers to be passed to all API requests.
     * Useful for setting an authentication token.
     *
     * @param key Header key
     * @param value Header value
     */
    setDefaultHeader: (key: string, value: string) => void;
    private fetchResponseBody;
}
